@@ -2,8 +2,8 @@
 # /usr/bin/env python
 """
 Author: qhsdk
-date: 2020/2/13 21:22
-desc: 存储和读取Token文件
+Date: 2020/12/28 21:22
+Desc: 存储和读取 token 文件
 """
 import os
 
